@@ -154,8 +154,8 @@ def update_version_to_release() -> None:
             f"{new_version}")
 
         sed(_source('etc/docker/kubeflow/Dockerfile'),
-            r"elyra\[all\]==.*",
-            f"elyra\[all\]=={new_version}")
+            r"elyra\[kfp-tekton,kfp-examples\]==.*",
+            f"elyra\[kfp-tekton,kfp-examples\]=={new_version}")
         sed(_source('etc/docker/elyra/Dockerfile'),
             r"    cd /tmp/elyra && make UPGRADE_STRATEGY=eager install && rm -rf /tmp/elyra",
             f"    cd /tmp/elyra \&\& git checkout tags/v{new_version} -b v{new_version} \&\& make UPGRADE_STRATEGY=eager install \&\& rm -rf /tmp/elyra")
@@ -276,8 +276,6 @@ def checkout_code() -> None:
     os.makedirs(config.work_dir)
     print(f'Cloning : {config.git_url} to {config.work_dir}')
     check_run(['git', 'clone', config.git_url], cwd=config.work_dir)
-    print(f'Checking out branch : {config.git_branch} in {config.source_dir}')
-    check_run(['git', 'checkout', '-b', config.git_branch, f'origin/{config.git_branch}'], cwd=config.source_dir)
     check_run(['git', 'config', 'user.name', config.git_user_name], cwd=config.source_dir)
     check_run(['git', 'config', 'user.email', config.git_user_email], cwd=config.source_dir)
 
@@ -446,11 +444,11 @@ def prepare_runtime_extensions_package_release() -> None:
     print("---------------- Preparing Individual Packages ------------------")
     print("-----------------------------------------------------------------")
 
-    packages = {'kfp-notebook': ['kfp>=1.6.3'],
-                'airflow-notebook': ['pygithub', 'black']}
+    packages = {'kfp-notebook':['kfp>=1.6.3'],
+                'airflow-notebook':['pygithub', 'black']}
 
-    packages_source = {'kfp-notebook': 'kfp',
-                       'airflow-notebook': 'airflow'}
+    packages_source = {'kfp-notebook':'kfp',
+                      'airflow-notebook':'airflow'}
 
     for package in packages:
         package_source_dir = os.path.join(config.work_dir, package)
@@ -608,7 +606,6 @@ def initialize_config(args=None) -> SimpleNamespace:
 
     configuration = {
         'goal': args.goal,
-        'git_branch': "v3.2.x",
         'git_url': DEFAULT_GIT_URL,
         'git_extension_package_url': DEFAULT_EXTENSION_PACKAGE_GIT_URL,
         'git_hash': 'HEAD',
@@ -654,8 +651,6 @@ def print_config() -> None:
         print(f'RC number \t\t -> {config.rc}')
     if config.beta is not None:
         print(f'Beta number \t\t -> {config.beta}')
-    if config.git_branch is not None:
-        print(f'Branch \t\t\t -> {config.git_branch}')
     print(f'Dev Version \t\t -> {config.dev_version}')
     print(f'Dev NPM Version \t -> {config.dev_npm_version}')
     print(f'Release Tag \t\t -> {config.tag}')
