@@ -1,5 +1,5 @@
 #
-# Copyright 2018-2020 Elyra Authors
+# Copyright 2018-2021 Elyra Authors
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -47,15 +47,11 @@ SEVERITY = {ValidationSeverity.Error: 'Error',
 
 def _get_runtime_type(runtime_config: Optional[str]) -> Optional[str]:
     if not runtime_config or runtime_config == 'local':
-        # No runtime configuration was  specified or it is local.
+        # No runtime configuration was specified or it is local.
         # Cannot use metadata manager to determine the runtime type.
-        return runtime_config
-
-    if runtime_config == 'local':
-        return runtime_config
-
+        return 'local'
     try:
-        metadata_manager = MetadataManager(namespace='runtimes')
+        metadata_manager = MetadataManager(schemaspace='runtimes')
         metadata = metadata_manager.get(runtime_config)
         return metadata.schema_name
     except Exception as e:
@@ -135,7 +131,7 @@ def _preprocess_pipeline(pipeline_path: str,
     if runtime:
         primary_pipeline.set("runtime", runtime)
     if runtime_config:
-        primary_pipeline.set("runtime-config", runtime_config)
+        primary_pipeline.set("runtime_config", runtime_config)
 
     return pipeline_definition.to_dict()
 
@@ -259,10 +255,15 @@ def validate(pipeline_path, runtime_config='local'):
 
 @click.command()
 @click.argument('pipeline_path')
+@click.option('--json',
+              'json_option',
+              is_flag=True,
+              required=False,
+              help='Display pipeline summary in JSON format')
 @click.option('--runtime-config',
               required=True,
               help='Runtime config where the pipeline should be processed')
-def submit(pipeline_path, runtime_config):
+def submit(json_option, pipeline_path, runtime_config):
     """
     Submit a pipeline to be executed on the server
     """
@@ -283,33 +284,40 @@ def submit(pipeline_path, runtime_config):
     with yaspin(text="Submitting pipeline..."):
         response: PipelineProcessorResponse = _execute_pipeline(pipeline_definition)
 
-    if response:
-        msg = []
-        # If there's a git_url attr, assume Apache Airflow DAG repo.
-        # TODO: this will need to be revisited once front-end is decoupled from runtime platforms.
-        if hasattr(response, 'git_url'):
-            msg.append(f"Apache Airflow DAG has been pushed to: {response.git_url}")
-        msg.extend(
-            [
-                f"Check the status of your job at: {response.run_url}",
-                f"The results and outputs are in the {response.object_storage_path} ",
-                f"working directory in {response.object_storage_url}"
-            ]
-        )
-        print_info("Job submission succeeded", msg)
-
-    click.echo()
-
-    print_banner("Elyra Pipeline Submission Complete")
+    if not json_option:
+        if response:
+            msg = []
+            # If there's a git_url attr, assume Apache Airflow DAG repo.
+            # TODO: this will need to be revisited once front-end is decoupled from runtime platforms.
+            if hasattr(response, 'git_url'):
+                msg.append(f"Apache Airflow DAG has been pushed to: {response.git_url}")
+            msg.extend(
+                [
+                    f"Check the status of your job at: {response.run_url}",
+                    f"The results and outputs are in the {response.object_storage_path} ",
+                    f"working directory in {response.object_storage_url}"
+                ]
+            )
+            print_info("Job submission succeeded", msg)
+        click.echo()
+        print_banner("Elyra Pipeline Submission Complete")
+    else:
+        if response:
+            click.echo()
+            print(json.dumps(response.to_json(), indent=4))
 
 
 @click.command()
+@click.option('--json',
+              'json_option',
+              is_flag=True,
+              required=False,
+              help='Display pipeline summary in JSON format')
 @click.argument('pipeline_path')
-def run(pipeline_path):
+def run(json_option, pipeline_path):
     """
     Run a pipeline in your local environment
     """
-
     click.echo()
 
     print_banner("Elyra Pipeline Local Run")
@@ -321,11 +329,15 @@ def run(pipeline_path):
 
     _validate_pipeline_definition(pipeline_definition)
 
-    _execute_pipeline(pipeline_definition)
+    response = _execute_pipeline(pipeline_definition)
 
-    click.echo()
-
-    print_banner("Elyra Pipeline Local Run Complete")
+    if not json_option:
+        click.echo()
+        print_banner("Elyra Pipeline Local Run Complete")
+    else:
+        click.echo()
+        if response:
+            print(json.dumps(response.to_json(), indent=4))
 
 
 @click.command()
@@ -344,68 +356,56 @@ def describe(json_option, pipeline_path):
 
     print_banner("Elyra Pipeline details")
 
+    indent_length = 4
+    blank_field = "Not Specified"
+    blank_list = ["None Listed"]
+    pipeline_keys = ["name", "description", "type", "version", "nodes", "file_dependencies", "component_dependencies"]
+    iter_keys = {"file_dependencies", "component_dependencies"}
+
     _validate_pipeline_file_extension(pipeline_path)
 
-    pipeline_definition = _preprocess_pipeline(pipeline_path)
+    pipeline_definition = \
+        _preprocess_pipeline(pipeline_path, runtime='local', runtime_config='local')
 
-    indent_length = 4
+    primary_pipeline = PipelineDefinition(pipeline_definition=pipeline_definition).primary_pipeline
 
-    blank_field = "Not Specified"
+    describe_dict = OrderedDict()
 
-    blank_list = ["None Listed"]
+    describe_dict["name"] = primary_pipeline.name
+    describe_dict["description"] = primary_pipeline.get_property('description')
+    describe_dict["type"] = primary_pipeline.type
+    describe_dict["version"] = primary_pipeline.version
+    describe_dict["nodes"] = len(primary_pipeline.nodes)
+    describe_dict["file_dependencies"] = set()
+    describe_dict["component_dependencies"] = set()
+    for node in primary_pipeline.nodes:
+        # collect information about file dependencies
+        for dependency in node.get_component_parameter("dependencies", []):
+            describe_dict["file_dependencies"].add(f"{dependency}")
+        # collect information about component dependencies
+        if node.component_source is not None:
+            describe_dict["component_dependencies"].add(node.component_source)
 
-    pipeline_keys = ["name", "description", "type", "version", "nodes", "file_dependencies"]
-
-    iter_keys = {"file_dependencies"}
-
-    for current_pipeline in pipeline_definition.get("pipelines", list()):
-
-        describe_dict = OrderedDict()
-
-        pipeline_data = current_pipeline.get("app_data", dict())
-
-        properties = pipeline_data.get("properties", dict())
-
-        # If the name is actually the same as the blank_field, it will seem as if there is no name
-        # The same can be said for all single fields
-        # The same issue happens with iterable fields and the blank_list
-        describe_dict["name"] = properties.get("name")
-
-        describe_dict["description"] = properties.get("description")
-
-        describe_dict["type"] = properties.get("runtime")
-
-        describe_dict["version"] = pipeline_data.get("version")
-
-        describe_dict["nodes"] = len(current_pipeline.get("nodes", list()))
-
-        describe_dict["file_dependencies"] = set()
-        for node in current_pipeline.get("nodes", list()):
-            if "dependencies" in node.get("app_data", dict()).get("component_parameters", list()):
-                for dependency in \
-                        node.get("app_data", dict()).get("component_parameters", dict()).get("dependencies", list()):
-                    describe_dict["file_dependencies"].add(f"{dependency}")
-
-        if not json_option:
-            for key in pipeline_keys:
-                readable_key = ' '.join(key.title().split('_'))
-                if key in iter_keys:
-                    click.echo(f"{readable_key}:")
-                    if describe_dict.get(key, set()) == set():
-                        click.echo(f"{' ' * indent_length}{blank_list[0]}")
-                    else:
-                        for item in describe_dict.get(key, blank_list):
-                            click.echo(f"{' ' * indent_length}{item}")
+    if not json_option:
+        for key in pipeline_keys:
+            readable_key = ' '.join(key.title().split('_'))
+            if key in iter_keys:
+                click.echo(f"{readable_key}:")
+                if describe_dict.get(key, set()) == set():
+                    click.echo(f"{' ' * indent_length}{blank_list[0]}")
                 else:
-                    click.echo(f"{readable_key}: {describe_dict.get(key, blank_field)}")
-        else:
-            for key in iter_keys:
-                describe_dict[key] = list(describe_dict[key])
-            for key in pipeline_keys:
-                value = describe_dict.get(key)
-                if value is None or (key in iter_keys and len(value) == 0):
-                    describe_dict.pop(key)
-            click.echo(json.dumps(describe_dict, indent=indent_length))
+                    for item in describe_dict.get(key, blank_list):
+                        click.echo(f"{' ' * indent_length}- {item}")
+            else:
+                click.echo(f"{readable_key}: {describe_dict.get(key, blank_field)}")
+    else:
+        for key in iter_keys:
+            describe_dict[key] = list(describe_dict[key])
+        for key in pipeline_keys:
+            value = describe_dict.get(key)
+            if value is None or (key in iter_keys and len(value) == 0):
+                describe_dict.pop(key)
+        click.echo(json.dumps(describe_dict, indent=indent_length))
 
 
 pipeline.add_command(describe)
