@@ -330,8 +330,8 @@ class MockMetadataTest(Metadata):
             d['post_property'] = self.post_property
         return d
 
-    def post_load(self, **kwargs: Any) -> None:
-        super().post_load(**kwargs)
+    def on_load(self, **kwargs: Any) -> None:
+        super().on_load(**kwargs)
         self.post_property = self.display_name
 
     def pre_save(self, **kwargs: Any) -> None:
