@@ -16,12 +16,13 @@
 
 import { MetadataWidget } from '@elyra/metadata-common';
 import { PIPELINE_CURRENT_VERSION } from '@elyra/pipeline-editor';
+import { RequestHandler } from '@elyra/services';
 import {
   containerIcon,
   pipelineIcon,
   RequestErrors,
   runtimesIcon,
-  pipelineComponentsIcon
+  componentCatalogIcon
 } from '@elyra/ui-components';
 
 import {
@@ -38,9 +39,8 @@ import { DocumentWidget } from '@jupyterlab/docregistry';
 import { IFileBrowserFactory } from '@jupyterlab/filebrowser';
 import { ILauncher } from '@jupyterlab/launcher';
 import { IMainMenu } from '@jupyterlab/mainmenu';
-import { addIcon } from '@jupyterlab/ui-components';
+import { addIcon, LabIcon } from '@jupyterlab/ui-components';
 
-import { getRuntimeIcon } from './pipeline-hooks';
 import { PipelineEditorFactory, commandIDs } from './PipelineEditorWidget';
 import { PipelineService, RUNTIMES_SCHEMASPACE } from './PipelineService';
 import {
@@ -48,15 +48,28 @@ import {
   RuntimeImagesWidget
 } from './RuntimeImagesWidget';
 import { RuntimesWidget } from './RuntimesWidget';
-import { SubmitNotebookButtonExtension } from './SubmitNotebookButtonExtension';
-import { SubmitScriptButtonExtension } from './SubmitScriptButtonExtension';
+import { SubmitFileButtonExtension } from './SubmitFileButtonExtension';
 
 import '../style/index.css';
 
-const PIPELINE_FACTORY = 'Pipeline Editor';
+const PIPELINE_EDITOR = 'Pipeline Editor';
 const PIPELINE = 'pipeline';
 const PIPELINE_EDITOR_NAMESPACE = 'elyra-pipeline-editor-extension';
-const COMPONENT_REGISTRY_SCHEMASPACE = 'component-registries';
+const COMPONENT_CATALOGS_SCHEMASPACE = 'component-catalogs';
+
+const createRemoteIcon = async ({
+  name,
+  url
+}: {
+  name: string;
+  url: string;
+}): Promise<LabIcon> => {
+  const svgstr = await RequestHandler.makeServerRequest<string>(url, {
+    method: 'GET',
+    type: 'text'
+  });
+  return new LabIcon({ name, svgstr });
+};
 
 /**
  * Initialization data for the pipeline-editor-extension extension.
@@ -85,7 +98,7 @@ const extension: JupyterFrontEndPlugin<void> = {
 
     // Set up new widget Factory for .pipeline files
     const pipelineEditorFactory = new PipelineEditorFactory({
-      name: PIPELINE_FACTORY,
+      name: PIPELINE_EDITOR,
       fileTypes: [PIPELINE],
       defaultFor: [PIPELINE],
       shell: app.shell,
@@ -121,7 +134,7 @@ const extension: JupyterFrontEndPlugin<void> = {
       command: commandIDs.openDocManager,
       args: widget => ({
         path: widget.context.path,
-        factory: PIPELINE_FACTORY
+        factory: PIPELINE_EDITOR
       }),
       name: widget => widget.context.path
     });
@@ -152,30 +165,37 @@ const extension: JupyterFrontEndPlugin<void> = {
     const openPipelineEditorCommand: string = commandIDs.openPipelineEditor;
     app.commands.addCommand(openPipelineEditorCommand, {
       label: (args: any) => {
-        return args['isPalette']
-          ? 'New Pipeline Editor'
-          : args.runtime?.display_name
-          ? args.isMenu
-            ? `${args.runtime?.display_name} Pipeline Editor`
-            : 'Pipeline Editor'
-          : 'Generic Pipeline Editor';
-      },
-      caption: (args: any) =>
-        args.runtime?.display_name
-          ? `${args.runtime?.display_name} Pipeline Editor`
-          : 'Generic Pipeline Editor',
-      iconLabel: (args: any) =>
-        args['isPalette']
-          ? ''
-          : args.runtime?.display_name
-          ? `${args.runtime?.display_name} Pipeline Editor`
-          : 'Generic Pipeline Editor',
-      icon: (args: any) => {
-        if (args['isPalette']) {
-          return undefined;
-        } else {
-          return getRuntimeIcon(args.runtime?.name);
+        if (args.isPalette) {
+          return `New ${PIPELINE_EDITOR}`;
         }
+        if (args.runtimeType?.id === 'LOCAL') {
+          return `Generic ${PIPELINE_EDITOR}`;
+        }
+        if (args.isMenu) {
+          return `${args.runtimeType?.display_name} ${PIPELINE_EDITOR}`;
+        }
+        return PIPELINE_EDITOR;
+      },
+      caption: (args: any) => {
+        if (args.runtimeType?.id === 'LOCAL') {
+          return `Generic ${PIPELINE_EDITOR}`;
+        }
+        return `${args.runtimeType?.display_name} ${PIPELINE_EDITOR}`;
+      },
+      iconLabel: (args: any) => {
+        if (args.isPalette) {
+          return '';
+        }
+        if (args.runtimeType?.id === 'LOCAL') {
+          return `Generic ${PIPELINE_EDITOR}`;
+        }
+        return `${args.runtimeType?.display_name} ${PIPELINE_EDITOR}`;
+      },
+      icon: (args: any) => {
+        if (args.isPalette) {
+          return undefined;
+        }
+        return args.runtimeType?.icon;
       },
       execute: (args: any) => {
         // Creates blank file, then opens it in a new window
@@ -186,6 +206,10 @@ const extension: JupyterFrontEndPlugin<void> = {
             ext: '.pipeline'
           })
           .then(async model => {
+            const platformId = args.runtimeType?.id;
+            const runtime_type =
+              platformId === 'LOCAL' ? undefined : platformId;
+
             const pipelineJson = {
               doc_type: 'pipeline',
               version: '3.0',
@@ -202,7 +226,7 @@ const extension: JupyterFrontEndPlugin<void> = {
                       comments: []
                     },
                     version: PIPELINE_CURRENT_VERSION,
-                    runtime: args.runtime?.name
+                    runtime_type
                   },
                   runtime_ref: ''
                 }
@@ -213,7 +237,7 @@ const extension: JupyterFrontEndPlugin<void> = {
               commandIDs.openDocManager,
               {
                 path: model.path,
-                factory: PIPELINE_FACTORY
+                factory: PIPELINE_EDITOR
               }
             );
             newWidget.context.ready.then(() => {
@@ -232,47 +256,45 @@ const extension: JupyterFrontEndPlugin<void> = {
       category: 'Elyra'
     });
 
-    PipelineService.getRuntimesSchema().then(
-      (schema: any) => {
+    PipelineService.getRuntimeTypes()
+      .then(async types => {
+        const promises = types.map(async t => {
+          return {
+            ...t,
+            icon: await createRemoteIcon({
+              name: `elyra:platform:${t.id}`,
+              url: t.icon
+            })
+          };
+        });
+
+        const resolvedTypes = await Promise.all(promises);
+
         // Add the command to the launcher
         if (launcher) {
-          launcher.add({
-            command: openPipelineEditorCommand,
-            category: 'Elyra',
-            rank: 1
-          });
-          for (const runtime of schema) {
+          for (const t of resolvedTypes as any) {
             launcher.add({
               command: openPipelineEditorCommand,
               category: 'Elyra',
-              args: { runtime },
-              rank:
-                runtime.name === 'kfp' ? 2 : runtime.name === 'airflow' ? 3 : 4
+              args: { runtimeType: t },
+              rank: t.id === 'LOCAL' ? 1 : 2
             });
+            menu.fileMenu.newMenu.addGroup(
+              [
+                {
+                  command: openPipelineEditorCommand,
+                  args: { runtimeType: t, isMenu: true }
+                }
+              ],
+              t.id === 'LOCAL' ? 30 : 31
+            );
           }
         }
-        // Add new pipeline to the file menu
-        menu.fileMenu.newMenu.addGroup(
-          [{ command: openPipelineEditorCommand, args: { isMenu: true } }],
-          30
-        );
-        for (const runtime of schema) {
-          menu.fileMenu.newMenu.addGroup(
-            [
-              {
-                command: openPipelineEditorCommand,
-                args: { runtime, isMenu: true }
-              }
-            ],
-            runtime.name === 'kfp' ? 31 : runtime.name === 'airflow' ? 32 : 33
-          );
-        }
-      },
-      (error: any) => RequestErrors.serverError(error)
-    );
+      })
+      .catch(error => RequestErrors.serverError(error));
 
     // SubmitNotebookButtonExtension initialization code
-    const notebookButtonExtension = new SubmitNotebookButtonExtension();
+    const notebookButtonExtension = new SubmitFileButtonExtension();
     app.docRegistry.addWidgetExtension('Notebook', notebookButtonExtension);
     app.contextMenu.addItem({
       selector: '.jp-Notebook',
@@ -281,7 +303,7 @@ const extension: JupyterFrontEndPlugin<void> = {
     });
 
     // SubmitScriptButtonExtension initialization code
-    const scriptButtonExtension = new SubmitScriptButtonExtension();
+    const scriptButtonExtension = new SubmitFileButtonExtension();
     app.docRegistry.addWidgetExtension('Python Editor', scriptButtonExtension);
     app.contextMenu.addItem({
       selector: '.elyra-ScriptEditor',
@@ -302,7 +324,8 @@ const extension: JupyterFrontEndPlugin<void> = {
       display_name: 'Runtimes',
       schemaspace: RUNTIMES_SCHEMASPACE,
       icon: runtimesIcon,
-      schemaType: 'runtime'
+      titleContext: 'runtime configuration',
+      appendToTitle: true
     });
     const runtimesWidgetID = `elyra-metadata:${RUNTIMES_SCHEMASPACE}`;
     runtimesWidget.id = runtimesWidgetID;
@@ -317,28 +340,30 @@ const extension: JupyterFrontEndPlugin<void> = {
       themeManager,
       display_name: 'Runtime Images',
       schemaspace: RUNTIME_IMAGES_SCHEMASPACE,
-      icon: containerIcon
+      icon: containerIcon,
+      titleContext: 'runtime image'
     });
     const runtimeImagesWidgetID = `elyra-metadata:${RUNTIME_IMAGES_SCHEMASPACE}`;
     runtimeImagesWidget.id = runtimeImagesWidgetID;
     runtimeImagesWidget.title.icon = containerIcon;
     runtimeImagesWidget.title.caption = 'Runtime Images';
 
-    const componentRegistryWidget = new MetadataWidget({
+    const componentCatalogWidget = new MetadataWidget({
       app,
       themeManager,
-      display_name: 'Pipeline Components',
-      schemaspace: COMPONENT_REGISTRY_SCHEMASPACE,
-      icon: pipelineComponentsIcon
+      display_name: 'Component Catalogs', // TODO: This info should come from the server for all schemaspaces
+      schemaspace: COMPONENT_CATALOGS_SCHEMASPACE,
+      icon: componentCatalogIcon,
+      titleContext: 'component catalog'
     });
-    const componentRegistryWidgetID = `elyra-metadata:${COMPONENT_REGISTRY_SCHEMASPACE}`;
-    componentRegistryWidget.id = componentRegistryWidgetID;
-    componentRegistryWidget.title.icon = pipelineComponentsIcon;
-    componentRegistryWidget.title.caption = 'Pipeline Components';
+    const componentCatalogWidgetID = `elyra-metadata:${COMPONENT_CATALOGS_SCHEMASPACE}`;
+    componentCatalogWidget.id = componentCatalogWidgetID;
+    componentCatalogWidget.title.icon = componentCatalogIcon;
+    componentCatalogWidget.title.caption = 'Component Catalogs';
 
     restorer.add(runtimeImagesWidget, runtimeImagesWidgetID);
     app.shell.add(runtimeImagesWidget, 'left', { rank: 951 });
-    app.shell.add(componentRegistryWidget, 'left', { rank: 961 });
+    app.shell.add(componentCatalogWidget, 'left', { rank: 961 });
   }
 };
 export default extension;
