@@ -59,6 +59,31 @@ Cypress.Commands.add('createRuntimeConfig', ({ type } = {}): void => {
   cy.findByRole('button', { name: /save/i }).click();
 });
 
+Cypress.Commands.add('createExampleComponentCatalog', ({ type } = {}): void => {
+  cy.on('fail', e => {
+    console.error(
+      `Example catalog connectors do not appear to be installed.\n${e}`
+    );
+    throw new Error(
+      `Example catalog connectors do not appear to be installed.\n${e}`
+    );
+  });
+
+  cy.findByRole('tab', { name: /component catalogs/i }).click();
+  cy.findByRole('button', { name: /create new component catalog/i }).click();
+
+  if (type === 'kfp') {
+    cy.findByRole('menuitem', { name: /kubeflow pipelines/i }).click();
+  } else {
+    cy.findByRole('menuitem', { name: /apache airflow/i }).click();
+  }
+
+  cy.findByLabelText(/^name/i).type('Example Components');
+
+  // save it
+  cy.findByRole('button', { name: /save/i }).click();
+});
+
 Cypress.Commands.add('deleteFile', (name: string): void => {
   cy.exec(`find build/cypress-tests/ -name "${name}" -delete`, {
     failOnNonZeroExit: false
@@ -157,22 +182,14 @@ Cypress.Commands.add('checkTabMenuOptions', (fileType: string): void => {
   cy.get('[aria-label="Canvas"]').click({ force: true });
 });
 
-Cypress.Commands.add('expandPaletteCategory', ({ type } = {}): void => {
-  switch (type) {
-    case 'kfp':
-      cy.get('.palette-flyout-category[value="Preloaded KFP"]').click();
-      break;
-    case 'airflow':
-      cy.get('.palette-flyout-category[value="Preloaded Airflow"]').click();
-      break;
-    default:
-      cy.get('.palette-flyout-category[value="Elyra"]').click();
-      break;
-  }
-});
-
 Cypress.Commands.add('closeTab', (index: number): void => {
   cy.get('.lm-TabBar-tabCloseIcon:visible')
     .eq(index)
     .click();
 });
+
+Cypress.Commands.add('createNewScriptFile', (language: string): void => {
+  cy.get(
+    `.jp-LauncherCard[data-category="Elyra"][title="Create a new ${language} file"]:visible`
+  ).click();
+});
